#[repr(u8)]pub enum Tcmdres {
TCMDRES_0 = 0,
TCMDRES_1 = 1,
}Variants
TCMDRES_0 = 0
Trigger sequences interrupted by a high priority trigger exception will be automatically restarted.
TCMDRES_1 = 1
Trigger sequences interrupted by a high priority trigger exception will be resumed from the command executing before the exception.
Implementations