pub struct TexcNum(/* private fields */);Implementations
Sourceimpl TexcNum
impl TexcNum
Sourcepub const TEXC_NUM_0: Self
pub const TEXC_NUM_0: Self
No triggers have been interrupted by a high priority exception. Or CFG[TRES] = 1.
Sourcepub const TEXC_NUM_1: Self
pub const TEXC_NUM_1: Self
Trigger 0 has been interrupted by a high priority exception.
Sourcepub const TEXC_NUM_2: Self
pub const TEXC_NUM_2: Self
Trigger 1 has been interrupted by a high priority exception.
Sourcepub const TEXC_NUM_3: Self
pub const TEXC_NUM_3: Self
Associated trigger sequence has interrupted by a high priority exception.
Sourcepub const TEXC_NUM_4: Self
pub const TEXC_NUM_4: Self
Associated trigger sequence has interrupted by a high priority exception.
Sourcepub const TEXC_NUM_5: Self
pub const TEXC_NUM_5: Self
Associated trigger sequence has interrupted by a high priority exception.
Sourcepub const TEXC_NUM_6: Self
pub const TEXC_NUM_6: Self
Associated trigger sequence has interrupted by a high priority exception.
Sourcepub const TEXC_NUM_7: Self
pub const TEXC_NUM_7: Self
Associated trigger sequence has interrupted by a high priority exception.
Sourcepub const TEXC_NUM_8: Self
pub const TEXC_NUM_8: Self
Associated trigger sequence has interrupted by a high priority exception.
Sourcepub const TEXC_NUM_9: Self
pub const TEXC_NUM_9: Self
Associated trigger sequence has interrupted by a high priority exception.
Sourcepub const TEXC_NUM_65535: Self
pub const TEXC_NUM_65535: Self
Every trigger sequence has been interrupted by a high priority exception.